<?php

/************************************************************************/
/* Copyright Russell McGuire 2001-2005                                  */
/* Provided under Living Stones Software License Agreement              */
/* By using or sharing this software with others, you agree to be bound */
/* by the terms of that agreement.                                      */
/* E-mail russ.mcguire@seek-first.com if you don't have a copy          */
/************************************************************************/

/************************************************************************/
/* Living Stones Common Functions                                       */
/*                                                                      */
/*----------------------------------------------------------------------*/
/* Database functions - should provide some independence                */
/*                                                                      */
/* If you want to use a database other than MySQL, you can probably     */
/* modify these functions without having to change all the other        */
/* Living Stones scripts.                                               */
/*----------------------------------------------------------------------*/
/*                                                                      */
/* open_database() - open the Living Stones database in MySQL           */
/*                                                                      */
/* check_sql() - Check for any database errors and handle appropr.      */
/*                                                                      */
/* sql_getresult() - Perform an SQL query that returns a result         */
/*                                                                      */
/* sql_getrow() - Get a row out of the result set                       */
/*                                                                      */
/* sql_getone() - Get one value from the DB by submitting an SQL query  */
/*                                                                      */
/* sql_getid() - Get the id created by the most recent INSERT           */
/*                                                                      */
/* sql_numrows() - Find out how many rows are in the result             */
/*                                                                      */
/* sql_isrecord() - Find out if there are any matching records          */
/*                                                                      */
/* sql_dataseek() - Index into a result set                             */
/*                                                                      */
/* sql_check4LS() - Returns TRUE if Living Stones database exists.      */
/*                                                                      */
/* sql_check4table() - Returns TRUE if the specified table exists.      */
/*                                                                      */
/* sql_getfields() - Returns fieldnames for a table                     */
/*                                                                      */
/* sql_check4field() - Returns TRUE if the specified field exists.      */
/*                                                                      */
/* sql_adddb() - Creates the LS database if it doesn't exist.           */
/*                                                                      */
/* sql_addtable() - Creates the specified table if it doesn't exist.    */
/*                                                                      */
/* sql_addfield() - Adds the specified field if it doesn't exist.       */
/*                                                                      */
/************************************************************************/

/************************************************************************/
/* Constants                                                            */
/*                                                                      */
/* Change these to match your specific MySQL installation.              */
/*                                                                      */
/************************************************************************/
$LS_DB_HOST = "localhost";		/* Host name */
$LS_DB_USER = "chomesch"; 		/* User name */
$LS_DB_PWD = "andever";		/* Password  */
$LS_DB_NAME = "chomesch_lstones";		/* Database name */

/************************************************************************/
/*                                                                      */
/* Try to provide support for older versions of PHP                     */
/*                                                                      */
/************************************************************************/
if(sizeof($HTTP_POST_VARS) > sizeof($_POST)) $_POST = $HTTP_POST_VARS;
if(sizeof($HTTP_GET_VARS) > sizeof($_GET)) $_GET = $HTTP_GET_VARS;
if(sizeof($HTTP_SESSION_VARS) > sizeof($_SESSION)) $_SESSION = $HTTP_SESSION_VARS;
if(sizeof($HTTP_COOKIE_VARS) > sizeof($_COOKIE)) $_COOKIE = $HTTP_COOKIE_VARS;

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function open_database                                               */
/*                                                                      */
/* Takes all the steps required to open the Living Stones database      */
/*                                                                      */
/*----------------------------------------------------------------------*/

function open_database()
	{ /* open the database */
	global $LS_DB_HOST,$LS_DB_USER,$LS_DB_PWD,$LS_DB_NAME;

	/* first must successfully connect to MySQL */
	$db = @mysql_connect($LS_DB_HOST,$LS_DB_USER,$LS_DB_PWD);
	if(!$db)
		{ /* failed to connect */
		die("Failed to open connection to MySQL server.");
		}

	/* then must specifically open the living stones database */
	mysql_select_db($LS_DB_NAME);
	check_sql("select database $LS_DB_NAME.");
	} /* end of open_database function */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function check_sql                                                   */
/*                                                                      */
/* Performs error checking for the just performed sql query             */
/*                                                                      */
/*----------------------------------------------------------------------*/

function check_sql($query)
	{ /* check to make sure that the SQL call worked */
	if(mysql_errno() > 0)
		{
		echo "<BR />Query: $query\n";
		$message = "<BR />MySQL error ". mysql_errno() ." (in $_SERVER('REQUEST_URI'): " . mysql_error();
		die($message);
		}
	} /* end of check_sql function */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_getresult                                               */
/*                                                                      */
/* Performs a database query and returns the result                     */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_getresult($query)
	{
	$result = mysql_query($query);
	check_sql($query);

	return $result;
	} /* end of function sql_getresult */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_getrow                                                  */
/*                                                                      */
/* Extracts a row of data out of an SQL query result                    */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_getrow($result)
	{
	$row = mysql_fetch_row($result);
	check_sql("get row");

	return $row;
	} /* end of function sql_getrow */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_getone                                                  */
/*                                                                      */
/* Extracts a single data item out of an SQL query                      */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_getone($query)
	{
	$result = sql_getresult($query);
	$row = sql_getrow($result);
	
	return $row[0];
	} /* end of function sql_getrow */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_getid                                                   */
/*                                                                      */
/* Get the auto_incremented id created by the most recent SQL Insert    */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_getid()
	{
	$id = mysql_insert_id();

	return $id;
	} /* end of function sql_getid */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_numrows                                                 */
/*                                                                      */
/* Find out how many rows are in the result                             */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_numrows($result)
	{
	$num = mysql_num_rows($result);

	return $num;
	} /* end of function sql_numrows */

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_isrecord                                                */
/*                                                                      */
/* Find out if there are any matching rows                              */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_isrecord($query)
	{
	$result = sql_getresult($query);

	if(sql_numrows($result) > 0) return TRUE;
	else return FALSE;
	} /* end of function sql_isrecord */


/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_dataseek                                                */
/*                                                                      */
/* Index into the result set                                            */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_dataseek($result,$indx)
	{
	mysql_data_seek($result,$indx);
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_check4LS                                                */
/*                                                                      */
/* Returns TRUE if the Living Stones database (defined above in         */
/*  LS_DB_NAME) exists on the server, and returns FALSE if it doesn't.  */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_check4LS()
	{
	global $LS_DB_NAME;
	$result = mysql_list_dbs()
		or die ("Field Lookup Failed");

	while($row = sql_getrow($result))
		if($row[0] == $LS_DB_NAME) return TRUE;

	return FALSE;
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_check4table                                             */
/*                                                                      */
/* Returns TRUE if the specified table exists in the LS database,       */
/* and returns FALSE if it doesn't.                                     */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_check4table($tablename)
	{
	global $LS_DB_NAME;
	$result = mysql_list_tables($LS_DB_NAME)
		or die ("Field Lookup Failed");

	while($row = sql_getrow($result))
		if($row[0] == $tablename) return TRUE;

	return FALSE;
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_getfields                                               */
/*                                                                      */
/* Return the fieldnames for a specified table.                         */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_getfields($tablename)
	{
	global $LS_DB_NAME;
	$result = mysql_list_fields($LS_DB_NAME,$tablename)
		or die ("Field Lookup Failed");

	for($i = 0; $i < mysql_num_fields($result); $i++)
		$names[$i] = mysql_field_name($result,$i);

	return $names;
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_check4field                                             */
/*                                                                      */
/* Returns TRUE if the specified field exists in the specified table    */
/* in the LS database and returns FALSE if it doesn't.                  */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_check4field($tablename,$fieldname)
	{
	$fields = sql_getfields($tablename);

	for($i=0; $i < count($fields); $i++)
		if($fields[$i] == $fieldname) return TRUE;

	return FALSE;
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_adddb                                                   */
/*                                                                      */
/* Creates the Living Stones database (defined above in LS_DB_NAME) if  */
/*  it doesn't yet exist.                                               */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_adddb()
	{
	global $LS_DB_NAME;

	if (sql_check4LS()) return;
	
	else
		{
		if(mysql_create_db($LS_DB_NAME))
			return;
		else
			die ("Count not create database $LS_DB_NAME");
		}
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_addtable                                                */
/*                                                                      */
/* Creates the specified table in the Living Stones database            */
/*  if it doesn't yet exist.                                            */
/*                                                                      */
/* Note: We assume that all LS tables will have an id field as index.   */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_addtable($tablename)
	{
	if (sql_check4table($tablename)) return;
	
	else
		{
		$query = "CREATE TABLE ".addslashes($tablename).
			" (id INTEGER UNSIGNED AUTO_INCREMENT PRIMARY KEY)";
		sql_getresult($query);
		return;
		}
	}

/*----------------------------------------------------------------------*/
/*                                                                      */
/* Function sql_addfield                                                */
/*                                                                      */
/* Creates the specified field in the specified table                   */
/*  if it doesn't yet exist.                                            */
/*                                                                      */
/*----------------------------------------------------------------------*/

function sql_addfield($tablename,$fieldname,$fieldtype)
	{
	if (sql_check4field($tablename,$fieldname)) return;
	
	else
		{
		$query = "ALTER TABLE ".addslashes($tablename).
			" ADD ".addslashes($fieldname)." ".addslashes($fieldtype);
		sql_getresult($query);
		return;
		}
	}



?>
