<?php
/************************************************************************/
/* Copyright Russell McGuire 2001-2007                                  */
/* Provided under Living Stones Software License Agreement              */
/* By using or sharing this software with others, you agree to be bound */
/* by the terms of that agreement.                                      */
/* E-mail russ.mcguire@seek-first.com if you don't have a copy          */
/************************************************************************/

/************************************************************************/
/* Living Stones Building Block                                         */
/*                                                                      */
/* Name: Manage People                                                  */
/*                                                                      */
/* Description: This is the main interface for managing what users      */
/*  have access to what functions and what data.  It will dynamically   */
/*  adapt to the collection of building blocks that are installed on    */
/*  this system.  The actions that are available to any given user of   */
/*  this program are based on the authorizations for that user, so this */
/*  program can be used by the overall system administrator for broad   */
/*  system administration, or by individual users who have limited      */
/*  control over the access settings for a limited number of people for */
/*  a limited set of functions and/or data.                             */
/*                                                                      */
/*  For example, any user likely can use this program to control what   */
/*  data about themselves can be access by any other user or group of   */
/*  users.                                                              */
/*                                                                      */
/*  This building block is constructed as a standalone web page so that */
/*  it can immediately be used for security administration, however,    */
/*  you should feel free to redesign the page to match your overall     */
/*  site design.                                                        */
/*                                                                      */
/************************************************************************/

session_start();

/* get include files */
require_once("./ls_include/DBfunctions.php");
require_once("./ls_include/Authfunctions.php");

/* connect to the Living Stones database */
open_database();

$thisscript = "http://" . $_SERVER['SERVER_NAME'] . $_SERVER['SCRIPT_NAME'];
$thispage = $_SERVER['SCRIPT_NAME'];
$parts = explode("/",$thispage);
$thispage = $parts[(count($parts)-1)];

$query = "SELECT id,dbtable FROM ls_security_objects WHERE object_desc = 'People'";
$result = sql_getresult($query);
$row = sql_getrow($result);
$objecttype = $row[0];
$dbtable = $row[1];

/* find out who this user is, if they have logged in */
$thisuser = $_SESSION["lsuid"];

?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
 "http://www.w3.org/TR/xhtml11/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>Living Stones Manage People</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<link rel="stylesheet" type="text/css" href="./ls_include/lsadmin.css" />

<?php
echo "<!-- script: $thisscript page: $thispage -->\n";
/* if not already logged in, then we need to log-in */
/***  NOTE: If you've placed the login page somewhere other than ls_login.php, change that reference below ***/
if(strlen($thisuser) < 1) 
	{
	echo "<script language='javascript'>\n";
	echo "window.location = 'ls_login.php?return_path=$thisscript&message=".
		urlencode("Only registered users can access this page.  Please login.")."';\n";
	echo "</script>\n";
	}
?>

<SCRIPT LANGUAGE="JAVASCRIPT" TYPE="TEXT/JAVASCRIPT">
this.window.focus();
</SCRIPT>
</head>
<body onLoad='document.forms[0].elements[0].focus()'>

<?php
/************************************************************************/
/* Process Inputs                                                       */
/************************************************************************/
$peopleid = $_POST['peopleid'];
if(strlen($peopleid) < 1) $peopleid = sql_getone("SELECT PeopleId FROM ls_users WHERE id='$thisuser'");

$securitylevel = $_POST['securitylevel'];

/************************************************************************/
/* Update security levels                                               */
/************************************************************************/
$updatelevels = $_POST['updatelevels'];
if((strlen($updatelevels) > 0) AND (check_function_auth($thisuser,$objecttype,"Set Levels",1)))
	{ 
	$fieldname = $_POST['fieldname'];
	$fieldauth = $_POST['fieldauth'];
	$level_level = addslashes($_POST['level_level']);
	$level_name = addslashes($_POST['level_name']);
	
	if($securitylevel < 1)
		{
		$query = "INSERT INTO ls_security_levels SET auth_level='$level_level',".
			"auth_name='$level_name',object_type='$objecttype'";
		sql_getresult($query);
		$securitylevel = sql_getid();
		}
	else
		{
		$query = "UPDATE ls_security_levels SET auth_level='$level_level',auth_name='$level_name' ".
			"WHERE id='$securitylevel'";
		sql_getresult($query);
		}

	for($i = 1;$i <= count($fieldname); $i++)
		{
		$readauth = 0;
		$writeauth = 0;
		if($fieldauth[$i] > 0)
			$readauth = 1;
		if($fieldauth[$i] > 1)
			$writeauth = 1;

		$query = "SELECT id FROM ls_security_fields ".
			"WHERE level='$securitylevel' AND fieldname='".$fieldname[$i]."'";
		$result = sql_getresult($query);
		if($row = sql_getrow($result))
			sql_getresult("UPDATE ls_security_fields SET readauth='$readauth',".
				"writeauth='$writeauth' WHERE id='".$row[0]."'");
		else
			sql_getresult("INSERT INTO ls_security_fields SET level='$securitylevel',".
				"fieldname='".$fieldname[$i]."',readauth='$readauth',writeauth='$writeauth'");
		} /* end for looping through fields */
	} /* end if updatelevels - security levels updated */

/************************************************************************/
/* Update default security level                                        */
/************************************************************************/
$updatedefault = $_POST['updatedefault'];
if((strlen($updatedefault) > 0) AND (check_function_auth($thisuser,$objecttype,"Set Levels",1)))
	{ 
	$defaultlevel = $_POST['defaultlevel'];
	set_auth(0,$objecttype,0,$defaultlevel);
	} /* end if update default */

/************************************************************************/
/* Update basic people data                                             */
/************************************************************************/
$update = $_POST['update'];
if(strlen($update) > 0)
	{ 
	/* The people data has been updated */
	$query = "SELECT FirstName,LastName,Telephone,Telephone2,Email,Email2,".
		"Address,Address2,City,State,Zip,Country FROM ls_people WHERE id='$peopleid'";
	$result = sql_getresult($query);
	$row = sql_getrow($result);

	$firstname = addslashes($_POST['firstname']);
	if(strlen($firstname) < 1) $firstname = $row[0];

	$lastname = addslashes($_POST['lastname']);
	if(strlen($lastname) < 1) $lastname = $row[1];

	$telephone = addslashes($_POST['telephone']);
	if(strlen($telephone) < 1) $telephone = $row[2];

	$telephone2 = addslashes($_POST['telephone2']);
	if(strlen($telephone2) < 1) $telephone2 = $row[3];

	$email = addslashes($_POST['email']);
	if(strlen($email) < 1) $email = $row[4];

	$email2 = addslashes($_POST['email2']);
	if(strlen($email2) < 1) $email2 = $row[5];

	$address = addslashes($_POST['address']);
	if(strlen($address) < 1) $address = $row[6];

	$address2 = addslashes($_POST['address2']);
	if(strlen($address2) < 1) $address2 = $row[7];

	$city = addslashes($_POST['city']);
	if(strlen($city) < 1) $city = $row[8];

	$state = addslashes($_POST['state']);
	if(strlen($state) < 1) $state = $row[9];

	$zip = addslashes($_POST['zip']);
	if(strlen($zip) < 1) $zip = $row[10];

	$country = addslashes($_POST['country']);
	if(strlen($country) < 1) $country = $row[11];

	$query = "UPDATE ls_people SET FirstName='$firstname',".
		"LastName='$lastname',".
		"Telephone='$telephone',".
		"Telephone2='$telephone2',".
		"Email='$email',".
		"Email2='$email2',".
		"Address='$address',".
		"Address2='$address2',".
		"City='$city',".
		"State='$state',".
		"Zip='$zip',".
		"Country='$country' ".
		"WHERE id='$peopleid'";
	sql_getresult($query);
	} /* end if update - people data updated */

/************************************************************************/
/* Update users' access to user data                                    */
/************************************************************************/
$updateaccess = $_POST['updateaccess'];
if(strlen($updateaccess) > 0)
	{ 
	/* the information should exist in two arrays */
	$secuserid = $_POST['secuserid'];
	$secuserlevel = $_POST['secuserlevel'];

	/* loop through the entries */
	for($i = 0;$i < count($secuserid); $i++)
		{
		set_auth($secuserid[$i],$objecttype,$peopleid,$secuserlevel[$i]);
		} /* end for looping through entries */
	
	} /* end if updateaccess - users' access to people data updated */
?>

<?php
/************************************************************************/
/* The page starts here                                                 */
/************************************************************************/
?>
<div id="Box1">

<div id="Box11">
<a href="http://www.lstones.com/"><img border=0 src="http://www.lstones.com/LivingStones.gif"></a>
</div> <!-- Box11 -->

<div id="Box13">

<div id="Box131">
<span>Manage People</span>
</div> <!-- Box131 -->

</div> <!-- Box13 -->

</div> <!-- Box1 -->

<div id="Box3">

<div id="Box31">
<?php 
/* This will figure out what options to place in the left column menu */
create_admin_menu($thisuser,$thispage,$LS_ADMIN_THRESHOLD);
?>
</div> <!-- Box31 -->

<div id="Box33">
<div id="Box331">
<?php
/**********************************************************************/
/* If this user has authorization to define security levels...        */
/* then this is where it happens                                      */
/**********************************************************************/
if(check_function_auth($thisuser,$objecttype,"Set Levels",1))
	{
	echo "<p style=\"background-color: lightblue;\"><b>Manage People Security Levels</b></p>\n";

	/* get the field names */
	$fieldnames = sql_getfields($dbtable);

	/* manage individual security levels */
	
	echo "<form method=POST action=\"$thisscript\">\n";
	if($peopleid > 0) echo "<input type=hidden name=peopleid value=$peopleid>\n";
	echo "<table border=0 style=\"border-width: 0px;\">\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Level to Manage:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>\n";
	echo "<select name=securitylevel size=1 onChange=\"this.form.submit()\">\n";
	$query = "SELECT id,auth_name,auth_level FROM ls_security_levels ".
		"WHERE object_type='$objecttype' ORDER BY auth_level ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		echo "<option value=$row[0]";
		if($securitylevel == $row[0]) 
			{
			echo " selected";
			$thisname = stripslashes($row[1]);
			$thislevel = $row[2];
			}
		echo ">".stripslashes($row[1])." (".stripslashes($row[2]).")</option>\n";
		}
	echo "<option value=0";
	if($securitylevel == 0) 
		{
		echo " selected";
		}
	echo ">New Level</option>\n";
	echo "</select>\n";
	echo "</td>\n";
	echo "</tr>\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Level Name:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>".
		"<input type=text size=50 value=\"$thisname\" name=level_name></td>\n";
	echo "</tr>\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Security Level:</th>\n";
	echo "<td style=\"text-align: right;border-width: 0px;\">".
		"<input type=text size=5 value=\"$thislevel\" name=level_level></td>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=2>".
		"Enter a value 0 - 100 (100 = highest security)</td>\n";
	echo "</tr>\n";
	
	/* Note: Skipping field 0 since we don't want to bother folks with the id */
	for($i = 1; $i<count($fieldnames);$i++)
		{
		$query = "SELECT readauth,writeauth FROM ls_security_fields ".
			"WHERE level='$securitylevel' AND fieldname='$fieldnames[$i]'";
		$result = sql_getresult($query);
		$row = sql_getrow($result);

		echo "<tr><td style=\"border-width: 0px;\"></td>\n";
		echo "<td style=\"border-width: 0px;text-align: right;\">".stripslashes($fieldnames[$i]).
			"<input type=hidden name=fieldname[$i] value=\"$fieldnames[$i]\"></td>\n";
		echo "<td style=\"border-width: 0px;text-align: left;\" colspan=2>".
			"<select name=fieldauth[$i] size=1>\n".
			"<option value=0>None</option>\n".
			"<option value=1";
		if(($row[0] > 0) and ($row[1] < 1)) echo " selected";
		echo ">Read Only</option>\n".
			"<option value=2";
		if($row[1] > 0) echo " selected";
		echo ">Read+Write</option>\n".
			"</select></td></tr>\n";
		} /* end while looping through the fields */

	echo "<tr><td colspan=4 style=\"border-width: 0px;\">".
		"<input type=submit name=updatelevels value=\"Update Level\"></td></tr>\n";
	
	echo "</table>\n";
	echo "</form>\n";

	/* define the default security level for all users */

	echo "<p><b>Select the default access that all users will have to all people:</b></p>\n";

	$defaultlevel = get_level(0,$objecttype,0);
	echo "<form method=POST action=\"$thisscript\">\n";
	if($peopleid > 0) echo "<input type=hidden name=peopleid value=$peopleid>\n";
	echo "<table border=0 style=\"border-width: 0px;\">\n";
	
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Default User Access to All People:</th>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>\n";
	echo "<select name=defaultlevel size=1>\n";
	$query = "SELECT id,auth_name,auth_level FROM ls_security_levels ".
		"WHERE object_type='$objecttype' ORDER BY auth_level ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		echo "<option value=$row[0]";
		if($defaultlevel == $row[0]) 
			{
			echo " selected";
			}
		echo ">".stripslashes($row[1])." (".stripslashes($row[2]).")</option>\n";
		}
	echo "</select>\n";
	echo "</td>\n";
	echo "</tr>\n";
	echo "<tr><td colspan=4 style=\"border-width: 0px;\">".
		"<input type=submit name=updatedefault value=\"Set Default\"></td></tr>\n";
	
	echo "</table>\n";
	echo "</form>\n";

	} /* end if authorized to set levels */
?>
<?php
/**********************************************************************/
/* This section is for the basic people settings                      */
/**********************************************************************/
echo "<p style=\"background-color: lightblue;\"><b>Manage People</b></p>\n";
?>
<form method=POST action="<?php echo $thisscript;?>">
<table border=0 style="border-width: 0px;">
<?php

$query = "SELECT FirstName,LastName,Telephone,Telephone2,Email,Email2,".
	"Address,Address2,City,State,Zip,Country FROM ls_people WHERE id='$peopleid'";
$result = sql_getresult($query);
$row = sql_getrow($result);

$firstname = stripslashes($row[0]);
$lastname = stripslashes($row[1]);
$telephone = stripslashes($row[2]);
$telephone2 = stripslashes($row[3]);
$email = stripslashes($row[4]);
$email2 = stripslashes($row[5]);
$address = stripslashes($row[6]);
$address2 = stripslashes($row[7]);
$city = stripslashes($row[8]);
$state = stripslashes($row[9]);
$zip = stripslashes($row[10]);
$country = stripslashes($row[11]);

echo "<tr>\n";
echo "<th style=\"text-align: right;\">Select Person:</th>\n";
echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>\n";
echo "<select name=peopleid size=1 onChange=\"this.form.submit()\">\n";

/* if this user is an admin - they can set the level access to "all people" for each user */
if(check_function_auth($thisuser,$objecttype,"Set Levels",1))
	{
	echo "<option value=0";
	if($peopleid == 0) 
		{
		echo "selected";
		$username = "All Users";
		}
	echo ">Default for Access to All People</option>\n";
	} /* end if this is an admin with Set Levels access */

$query = "SELECT id,FirstName,LastName FROM ls_people ".
	"WHERE id>'0' ORDER BY LastName ASC";
$result = sql_getresult($query);
while($row=sql_getrow($result))
	{
	if(check_auth($thisuser,$objecttype,$row[0],$LS_USER_THRESHOLD))
		{
		echo "<option value=$row[0]";
		if($peopleid == $row[0]) 
			{
			echo " selected";
			$username = stripslashes($row[1])." ".stripslashes($row[2]);
			}
		echo ">".stripslashes($row[1])." ".stripslashes($row[2])."</option>\n";
		}
	}
echo "</select>\n";
echo "</td>\n";
echo "</tr>\n";

echo "<tr>\n";
echo "<th style=\"text-align: right;\">Name:</th>\n";
echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>";
$thisauth = get_field_auth($thisuser,$objecttype,$peopleid,"FirstName");
if(($thisauth > 0) AND ($peopleid > 0))
	{
	if($thisauth > 1) 
		echo "<input type=text size=25 value=\"$firstname\" name=firstname>\n";
	else 
		echo "$firstname\n";
	} /* end if authorized to at least view firstname */
$thisauth = get_field_auth($thisuser,$objecttype,$peopleid,"LastName");
if(($thisauth > 0) AND ($peopleid > 0))
	{
	if($thisauth > 1) 
		echo "<input type=text size=25 value=\"$lastname\" name=lastname>\n";
	else 
		echo "$lastname\n";
	} /* end if authorized to at least view lastname */
echo "</td></tr>\n";
	
$auth1 = get_field_auth($thisuser,$objecttype,$peopleid,"Telephone");
$auth2 = get_field_auth($thisuser,$objecttype,$peopleid,"Telephone2");
if((($auth1 > 0) OR ($auth2 > 0)) AND ($peopleid > 0))
	{
	echo "<tr>\n";
	echo "<td style=\"text-align: right;\"><b>Telephone Numbers:</b>";
	if($auth1 > 0) echo " Primary:</td>\n";
	else echo "</td>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\">";
	if($auth1 > 1) 
		echo "<input type=text size=15 value=\"$telephone\" name=telephone></td>\n";
	elseif($auth1 > 0) 
		echo "$telephone</td>\n";
	else echo "</td>\n";

	echo "<td style=\"text-align: right;\">";
	if($auth2 > 0) echo " Secondary:</td>\n";
	else echo "</td>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\">";
	if($auth2 > 1) 
		echo "<input type=text size=15 value=\"$telephone2\" name=telephone2></td>\n";
	elseif($auth2 > 0) 
		echo "$telephone2</td>\n";
	else echo "</td>\n";
	echo "</tr>\n";
	} /* end if authorized to view at least one telephone # */
	
$auth1 = get_field_auth($thisuser,$objecttype,$peopleid,"Email");
$auth2 = get_field_auth($thisuser,$objecttype,$peopleid,"Email2");
if((($auth1 > 0) OR ($auth2 > 0)) AND ($peopleid > 0))
	{
	echo "<tr>\n";
	echo "<td style=\"text-align: right;\"><b>E-mail Addresses:</b>";
	if($auth1 > 0) echo " Primary:</td>\n";
	else echo "</td>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\">";
	if($auth1 > 1) 
		echo "<input type=text size=25 value=\"$email\" name=email></td>\n";
	elseif($auth1 > 0) 
		echo "$email</td>\n";
	else echo "</td>\n";

	echo "<td style=\"text-align: right;\">";
	if($auth2 > 0) echo " Secondary:</td>\n";
	else echo "</td>\n";
	echo "<td style=\"text-align: left;border-width: 0px;\">";
	if($auth2 > 1) 
		echo "<input type=text size=25 value=\"$email2\" name=email2></td>\n";
	elseif($auth2 > 0) 
		echo "$email2</td>\n";
	else echo "</td>\n";
	echo "</tr>\n";
	} /* end if authorized to view at least one e-mail address */

$auth1 = get_field_auth($thisuser,$objecttype,$peopleid,"Address");
$auth2 = get_field_auth($thisuser,$objecttype,$peopleid,"Address2");
if((($auth1 > 0) OR ($auth2 > 0))  AND ($peopleid > 0))
	{
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Mailing Address:</th>\n";
	if($auth1 > 0)
		{
		echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>";
		if($auth1 > 1) 
			echo "<input type=text size=50 value=\"$address\" name=address></td>\n";
		else 
			echo "$address</td>\n";
		echo "</tr>\n";
		}

	if(($auth1 > 0) AND ($auth2 > 0))
		echo "<tr>\n<td></td>\n";
	
	if($auth2 > 0)
		{
		echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>";
		if($auth2 > 1) 
			echo "<input type=text size=50 value=\"$address2\" name=address2></td>\n";
		else 
			echo "$address2</td>\n";
		echo "</tr>\n";
		}
	} /* end if authorized to view at least one address line */

$auth1 = get_field_auth($thisuser,$objecttype,$peopleid,"City");
$auth2 = get_field_auth($thisuser,$objecttype,$peopleid,"State");
$auth3 = get_field_auth($thisuser,$objecttype,$peopleid,"Zip");

if((($auth1 > 0) OR ($auth2 > 0) OR ($auth3 > 0))  AND ($peopleid > 0))
	{
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">";
	if($auth1 > 0) echo "City ";
	if($auth2 > 0) echo "State ";
	if($auth3 > 0) echo "Zip ";
	echo ":</th>\n";

	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>";
	if($auth1 > 1) 
		echo "<input type=text size=15 value=\"$city\" name=city>\n";
	elseif($auth1 > 0) 
		echo "$city \n";

	if($auth2 > 1) 
		echo "<input type=text size=15 value=\"$state\" name=state>\n";
	elseif($auth2 > 0) 
		echo "$state \n";

	if($auth3 > 1) 
		echo "<input type=text size=10 value=\"$zip\" name=zip>\n";
	elseif($auth3 > 0) 
		echo "$zip \n";

	echo "</td></tr>\n";
	} /* end if authorized to at least see city, state, or zip */

$auth1 = get_field_auth($thisuser,$objecttype,$peopleid,"Country");
if(($auth1 > 0) AND ($peopleid > 0))
	{
	echo "<tr>\n";
	echo "<th style=\"text-align: right;\">Country:</th>";
	echo "<td style=\"text-align: left;border-width: 0px;\" colspan=3>";
	if($auth1 > 1) 
		echo "<input type=text size=25 value=\"$country\" name=country></td>\n";
	else 
		echo "$country</td>\n";
	echo "</tr>\n";
	} /* end if authorized to at least view country */

if($peopleid > 0)
	echo "<tr><td colspan=4 style=\"border-width: 0px;\">".
		"<input type=submit name=update value=\"Update\"></td></tr>\n";
?>
</table>
</form>
<?php
/**********************************************************************/
/* If this user has admin level for this person...                    */
/* then this is where we define access rights for other users         */
/**********************************************************************/
if(check_auth($thisuser,$objecttype,$peopleid,$LS_ADMIN_THRESHOLD))
	{
	echo "<p style=\"background-color: lightblue;\"><b>Manage Access by Users to this Person's Data</b></p>\n";

	echo "<p style=\"color: red;\"><b>Note: Any given user's access is defined by a combination of factors. ".
		"If you change their access, but their access doesn't appear to change, it's because that user ".
		"has a higher level of access:\n<ul style=\"color: red;\">\n".
		"<li>either as part of a group (which you can also control) or</li>".
		"\n<li>as their default level of access for all users (which is ".
		"only controllable by the system administrator).</li>\n</ul>\n</b></p>\n";
	
	/* list the levels for the user's reference */
	echo "<p><b>Security Level Definitions:</b></p>\n";
	echo "<table style=\"border-width: 0px;\">\n";
	echo "<tr><th></th><th>Read-only</th><th>Read+Write</th></tr>\n";
	$query = "SELECT id,auth_name,auth_level FROM ls_security_levels WHERE object_type='$objecttype' ".
			"ORDER BY auth_level ASC";
	$result = sql_getresult($query);
	$i = 0;
	while($row = sql_getrow($result))
		{
		/* store values for future reference */
		$levels[$i] = $row[0];
		$levelsname[$i] = stripslashes($row[1]);
		$i = $i+1;

		echo "<tr><th style=\"border: solid black 1px;\">".stripslashes($row[1])." ($row[2])</th>\n";
		echo "<td style=\"border: solid black 1px;padding: 5px;\">";
		$q2 = "SELECT fieldname FROM ls_security_fields WHERE level='$row[0]' ".
			"AND readauth='1' AND writeauth='0' ORDER BY fieldname ASC";
		$r2 = sql_getresult($q2);
		while($ro2 = sql_getrow($r2))
			echo stripslashes($ro2[0])."<br />";
		echo "</td>\n<td style=\"border: solid black 1px;padding: 5px;\">";
		$q2 = "SELECT fieldname FROM ls_security_fields WHERE level='$row[0]' ".
			"AND writeauth='1' ORDER BY fieldname ASC";
		$r2 = sql_getresult($q2);
		while($ro2 = sql_getrow($r2))
			echo stripslashes($ro2[0])."<br />";
		echo "</td></tr>\n";
		} /* end while looping through levels */
	echo "</table>\n";
	
	/* now, list users and their access */

	echo "<form method=POST action=\"$thisscript\">\n";
	if($peopleid > 0) echo "<input type=hidden name=peopleid value=$peopleid>\n";

	/* start with groups */

	echo "<p><b>Each Group's Access to $username's Data:</b></p>\n";
	echo "<table style=\"border-width: 0px;\">\n";
	$query = "SELECT ls_users.id,FirstName,LastName FROM ls_users,ls_people ".
		"WHERE ls_users.IsGroup > '0' AND ls_people.id=ls_users.PeopleId ORDER BY LastName ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		if(check_auth($thisuser,$objecttype,$row[0],$LS_USER_THRESHOLD))
			{
			$thisuserseclevel = get_level($row[0],$objecttype,$peopleid);

			echo "<tr><td style=\"border-width: 0px;\">";
			echo stripslashes($row[1])." ".stripslashes($row[2]).
				"<input type=hidden name=secuserid[] value=$row[0]></td>\n";
			echo "<td><select name=secuserlevel[] size=1>\n";
			for($i = 0;$i < count($levels);$i++)
				{
				echo "<option value=$levels[$i]";
				if($thisuserseclevel == $levels[$i]) echo " selected";
				echo ">$levelsname[$i]</option>\n";
				} /* end while looping through security levels */
			echo "</select></td></tr>\n";
			} /* end if have at least user access to this user */
		} /* end while looping through all groups */
	echo "</table>\n";

	/* now handle individual users */

	echo "<p><b>Each User's Access to $username's Data:</b></p>\n";
	echo "<table style=\"border-width: 0px;\">\n";
	$query = "SELECT ls_users.id,FirstName,LastName FROM ls_users,ls_people ".
		"WHERE ls_users.IsGroup = '0' AND ls_people.id=ls_users.PeopleId ORDER BY LastName ASC";
	$result = sql_getresult($query);
	while($row=sql_getrow($result))
		{
		if(check_auth($thisuser,$objecttype,$row[0],$LS_USER_THRESHOLD))
			{
			$thisuserseclevel = get_level($row[0],$objecttype,$peopleid);

			echo "<tr><td style=\"border-width: 0px;\">";
			echo stripslashes($row[1])." ".stripslashes($row[2]).
				"<input type=hidden name=secuserid[] value=$row[0]></td>\n";
			echo "<td><select name=secuserlevel[] size=1>\n";
			for($i = 0;$i < count($levels);$i++)
				{
				echo "<option value=$levels[$i]";
				if($thisuserseclevel == $levels[$i]) echo " selected";
				echo ">$levelsname[$i]</option>\n";
				} /* end while looping through security levels */
			echo "</select></td></tr>\n";
			} /* end if have at least user access to this user */
		} /* end while looping through all users */
	echo "</table>\n";

	/* Add the submit button */
	echo "<table border=0 style=\"border-width: 0px;\">\n";
	echo "<tr><td style=\"border-width: 0px;\">".
		"<input type=submit name=updateaccess value=\"Update User Access\"></td></tr>\n";
	echo "</table>\n";
	echo "</form>\n";
	} /* end if admin level access for this user - set access */
?>
</div> <!-- Box331 -->
</div> <!-- Box33 -->

</div> <!-- Box3 -->

<a href="http://www.lstones.com/"><img border=0 src="http://www.lstones.com/LS-sm.gif"></a>
</body>
</html>
